Class: Google::Apis::DisplayvideoV1::CombinedAudienceGroup
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV1::CombinedAudienceGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v1/classes.rb,
lib/google/apis/displayvideo_v1/representations.rb,
lib/google/apis/displayvideo_v1/representations.rb
Overview
Details of combined audience group. All combined audience targeting settings are logically ‘OR’ of each other.
Instance Attribute Summary collapse
Instance Method Summary collapse
-
#initialize(**args) ⇒ CombinedAudienceGroup
constructor
A new instance of CombinedAudienceGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CombinedAudienceGroup
Returns a new instance of CombinedAudienceGroup.
2740 2741 2742 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 2740 def initialize(**args) update!(**args) end |
Instance Attribute Details
#settings ⇒ Array<Google::Apis::DisplayvideoV1::CombinedAudienceTargetingSetting>
Required. All combined audience targeting settings in combined audience group.
Repeated settings with same id will be ignored. The number of combined
audience settings should be no more than five, error will be thrown otherwise.
Corresponds to the JSON property settings
2738 2739 2740 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 2738 def settings @settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2745 2746 2747 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 2745 def update!(**args) @settings = args[:settings] if args.key?(:settings) end |