Class: Google::Apis::DisplayvideoV1::ContentInstreamPositionAssignedTargetingOptionDetails
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV1::ContentInstreamPositionAssignedTargetingOptionDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v1/classes.rb,
lib/google/apis/displayvideo_v1/representations.rb,
lib/google/apis/displayvideo_v1/representations.rb
Overview
Assigned content instream position targeting option details. This will be
populated in the content_instream_position_details field when targeting_type
is TARGETING_TYPE_CONTENT_INSTREAM_POSITION.
Instance Attribute Summary collapse
-
#ad_type ⇒ String
Output only.
-
#content_instream_position ⇒ String
Required.
-
#targeting_option_id ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ContentInstreamPositionAssignedTargetingOptionDetails
constructor
A new instance of ContentInstreamPositionAssignedTargetingOptionDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ContentInstreamPositionAssignedTargetingOptionDetails
Returns a new instance of ContentInstreamPositionAssignedTargetingOptionDetails.
3017 3018 3019 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 3017 def initialize(**args) update!(**args) end |
Instance Attribute Details
#ad_type ⇒ String
Output only. The ad type to target. Only applicable to insertion order
targeting and new line items supporting the specified ad type will inherit
this targeting option by default. Possible values are: * AD_TYPE_VIDEO, the
setting will be inherited by new line item when line_item_type is
LINE_ITEM_TYPE_VIDEO_DEFAULT. * AD_TYPE_AUDIO, the setting will be
inherited by new line item when line_item_type is
LINE_ITEM_TYPE_AUDIO_DEFAULT.
Corresponds to the JSON property adType
3004 3005 3006 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 3004 def ad_type @ad_type end |
#content_instream_position ⇒ String
Required. The content instream position for video or audio ads.
Corresponds to the JSON property contentInstreamPosition
3009 3010 3011 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 3009 def content_instream_position @content_instream_position end |
#targeting_option_id ⇒ String
Required. The targeting_option_id field when targeting_type is
TARGETING_TYPE_CONTENT_INSTREAM_POSITION.
Corresponds to the JSON property targetingOptionId
3015 3016 3017 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 3015 def targeting_option_id @targeting_option_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
3022 3023 3024 3025 3026 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 3022 def update!(**args) @ad_type = args[:ad_type] if args.key?(:ad_type) @content_instream_position = args[:content_instream_position] if args.key?(:content_instream_position) @targeting_option_id = args[:targeting_option_id] if args.key?(:targeting_option_id) end |