Class: Google::Apis::DisplayvideoV1::ContentOutstreamPositionAssignedTargetingOptionDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v1/classes.rb,
lib/google/apis/displayvideo_v1/representations.rb,
lib/google/apis/displayvideo_v1/representations.rb

Overview

Assigned content outstream position targeting option details. This will be populated in the content_outstream_position_details field when targeting_type is TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ContentOutstreamPositionAssignedTargetingOptionDetails

Returns a new instance of ContentOutstreamPositionAssignedTargetingOptionDetails.



3079
3080
3081
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 3079

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#ad_typeString

Output only. The ad type to target. Only applicable to insertion order targeting and new line items supporting the specified ad type will inherit this targeting option by default. Possible values are: * AD_TYPE_DISPLAY, the setting will be inherited by new line item when line_item_type is LINE_ITEM_TYPE_DISPLAY_DEFAULT. * AD_TYPE_VIDEO, the setting will be inherited by new line item when line_item_type is LINE_ITEM_TYPE_VIDEO_DEFAULT. Corresponds to the JSON property adType

Returns:

  • (String)


3066
3067
3068
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 3066

def ad_type
  @ad_type
end

#content_outstream_positionString

Required. The content outstream position. Corresponds to the JSON property contentOutstreamPosition

Returns:

  • (String)


3071
3072
3073
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 3071

def content_outstream_position
  @content_outstream_position
end

#targeting_option_idString

Required. The targeting_option_id field when targeting_type is TARGETING_TYPE_CONTENT_OUTSTREAM_POSITION. Corresponds to the JSON property targetingOptionId

Returns:

  • (String)


3077
3078
3079
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 3077

def targeting_option_id
  @targeting_option_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3084
3085
3086
3087
3088
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 3084

def update!(**args)
  @ad_type = args[:ad_type] if args.key?(:ad_type)
  @content_outstream_position = args[:content_outstream_position] if args.key?(:content_outstream_position)
  @targeting_option_id = args[:targeting_option_id] if args.key?(:targeting_option_id)
end