Class: Google::Apis::DisplayvideoV1::CustomBiddingAlgorithm

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v1/classes.rb,
lib/google/apis/displayvideo_v1/representations.rb,
lib/google/apis/displayvideo_v1/representations.rb

Overview

A single custom bidding algorithm.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ CustomBiddingAlgorithm

Returns a new instance of CustomBiddingAlgorithm.



3854
3855
3856
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 3854

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Immutable. The unique ID of the advertiser that owns the custom bidding algorithm. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


3791
3792
3793
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 3791

def advertiser_id
  @advertiser_id
end

#custom_bidding_algorithm_idFixnum

Output only. The unique ID of the custom bidding algorithm. Assigned by the system. Corresponds to the JSON property customBiddingAlgorithmId

Returns:

  • (Fixnum)


3797
3798
3799
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 3797

def custom_bidding_algorithm_id
  @custom_bidding_algorithm_id
end

#custom_bidding_algorithm_stateString

Output only. The status of custom bidding algorithm. Corresponds to the JSON property customBiddingAlgorithmState

Returns:

  • (String)


3802
3803
3804
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 3802

def custom_bidding_algorithm_state
  @custom_bidding_algorithm_state
end

#custom_bidding_algorithm_typeString

Required. Immutable. The type of custom bidding algorithm. Corresponds to the JSON property customBiddingAlgorithmType

Returns:

  • (String)


3807
3808
3809
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 3807

def custom_bidding_algorithm_type
  @custom_bidding_algorithm_type
end

#display_nameString

Required. The display name of the custom bidding algorithm. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


3813
3814
3815
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 3813

def display_name
  @display_name
end

#entity_statusString

Controls whether or not the custom bidding algorithm can be used as a bidding strategy. Accepted values are: * ENTITY_STATUS_ACTIVE * ENTITY_STATUS_ARCHIVED Corresponds to the JSON property entityStatus

Returns:

  • (String)


3820
3821
3822
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 3820

def entity_status
  @entity_status
end

#model_readinessArray<Google::Apis::DisplayvideoV1::CustomBiddingModelReadinessState>

Output only. The state of custom bidding model readiness for each advertiser who has access. This field may only include the state of the queried advertiser if the algorithm owner is a partner and is being retrieved using an advertiser accessor. Corresponds to the JSON property modelReadiness



3831
3832
3833
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 3831

def model_readiness
  @model_readiness
end

#nameString

Output only. The resource name of the custom bidding algorithm. Corresponds to the JSON property name

Returns:

  • (String)


3836
3837
3838
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 3836

def name
  @name
end

#partner_idFixnum

Immutable. The unique ID of the partner that owns the custom bidding algorithm. Corresponds to the JSON property partnerId

Returns:

  • (Fixnum)


3841
3842
3843
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 3841

def partner_id
  @partner_id
end

#shared_advertiser_idsArray<Fixnum>

The IDs of the advertisers who have access to this algorithm. If advertiser_id is set, this field will only consist of that value. This field will not be set if the algorithm owner is a partner and is being retrieved using an advertiser accessor. Corresponds to the JSON property sharedAdvertiserIds

Returns:

  • (Array<Fixnum>)


3852
3853
3854
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 3852

def shared_advertiser_ids
  @shared_advertiser_ids
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3859
3860
3861
3862
3863
3864
3865
3866
3867
3868
3869
3870
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 3859

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @custom_bidding_algorithm_id = args[:custom_bidding_algorithm_id] if args.key?(:custom_bidding_algorithm_id)
  @custom_bidding_algorithm_state = args[:custom_bidding_algorithm_state] if args.key?(:custom_bidding_algorithm_state)
  @custom_bidding_algorithm_type = args[:custom_bidding_algorithm_type] if args.key?(:custom_bidding_algorithm_type)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @model_readiness = args[:model_readiness] if args.key?(:model_readiness)
  @name = args[:name] if args.key?(:name)
  @partner_id = args[:partner_id] if args.key?(:partner_id)
  @shared_advertiser_ids = args[:shared_advertiser_ids] if args.key?(:shared_advertiser_ids)
end