Class: Google::Apis::DisplayvideoV1::ExchangeConfigEnabledExchange

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v1/classes.rb,
lib/google/apis/displayvideo_v1/representations.rb,
lib/google/apis/displayvideo_v1/representations.rb

Overview

An enabled exchange in the partner.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExchangeConfigEnabledExchange

Returns a new instance of ExchangeConfigEnabledExchange.



4909
4910
4911
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 4909

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#exchangeString

The enabled exchange. Corresponds to the JSON property exchange

Returns:

  • (String)


4890
4891
4892
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 4890

def exchange
  @exchange
end

Output only. Agency ID of Google Ad Manager. The field is only relevant when Google Ad Manager is the enabled exchange. Corresponds to the JSON property googleAdManagerAgencyId

Returns:

  • (String)


4896
4897
4898
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 4896

def google_ad_manager_agency_id
  @google_ad_manager_agency_id
end

Output only. Network ID of Google Ad Manager. The field is only relevant when Google Ad Manager is the enabled exchange. Corresponds to the JSON property googleAdManagerBuyerNetworkId

Returns:

  • (String)


4902
4903
4904
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 4902

def google_ad_manager_buyer_network_id
  @google_ad_manager_buyer_network_id
end

#seat_idString

Output only. Seat ID of the enabled exchange. Corresponds to the JSON property seatId

Returns:

  • (String)


4907
4908
4909
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 4907

def seat_id
  @seat_id
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4914
4915
4916
4917
4918
4919
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 4914

def update!(**args)
  @exchange = args[:exchange] if args.key?(:exchange)
  @google_ad_manager_agency_id = args[:google_ad_manager_agency_id] if args.key?(:google_ad_manager_agency_id)
  @google_ad_manager_buyer_network_id = args[:google_ad_manager_buyer_network_id] if args.key?(:google_ad_manager_buyer_network_id)
  @seat_id = args[:seat_id] if args.key?(:seat_id)
end