Class: Google::Apis::DisplayvideoV1::ExitEvent

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v1/classes.rb,
lib/google/apis/displayvideo_v1/representations.rb,
lib/google/apis/displayvideo_v1/representations.rb

Overview

Exit event of the creative.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ExitEvent

Returns a new instance of ExitEvent.



4996
4997
4998
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 4996

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#nameString

The name of the click tag of the exit event. The name must be unique within one creative. Leave it empty or unset for creatives containing image assets only. Corresponds to the JSON property name

Returns:

  • (String)


4977
4978
4979
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 4977

def name
  @name
end

#reporting_nameString

The name used to identify this event in reports. Leave it empty or unset for creatives containing image assets only. Corresponds to the JSON property reportingName

Returns:

  • (String)


4983
4984
4985
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 4983

def reporting_name
  @reporting_name
end

#typeString

Required. The type of the exit event. Corresponds to the JSON property type

Returns:

  • (String)


4988
4989
4990
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 4988

def type
  @type
end

#urlString

Required. The click through URL of the exit event. This is required when type is: * EXIT_EVENT_TYPE_DEFAULT * EXIT_EVENT_TYPE_BACKUP Corresponds to the JSON property url

Returns:

  • (String)


4994
4995
4996
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 4994

def url
  @url
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5001
5002
5003
5004
5005
5006
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 5001

def update!(**args)
  @name = args[:name] if args.key?(:name)
  @reporting_name = args[:reporting_name] if args.key?(:reporting_name)
  @type = args[:type] if args.key?(:type)
  @url = args[:url] if args.key?(:url)
end