Class: Google::Apis::DisplayvideoV1::FirstAndThirdPartyAudience

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v1/classes.rb,
lib/google/apis/displayvideo_v1/representations.rb,
lib/google/apis/displayvideo_v1/representations.rb

Overview

Describes a first or third party audience list used for targeting. First party audiences are created via usage of client data. Third party audiences are provided by Third Party data providers and can only be licensed to customers.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FirstAndThirdPartyAudience

Returns a new instance of FirstAndThirdPartyAudience.



5139
5140
5141
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 5139

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_display_audience_sizeFixnum

Output only. The estimated audience size for the Display network in the past month. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only returned in GET request. Corresponds to the JSON property activeDisplayAudienceSize

Returns:

  • (Fixnum)


5021
5022
5023
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 5021

def active_display_audience_size
  @active_display_audience_size
end

#app_idString

The app_id matches with the type of the mobile_device_ids being uploaded. Only applicable to audience_type CUSTOMER_MATCH_DEVICE_ID Corresponds to the JSON property appId

Returns:

  • (String)


5027
5028
5029
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 5027

def app_id
  @app_id
end

#audience_sourceString

Output only. The source of the audience. Corresponds to the JSON property audienceSource

Returns:

  • (String)


5032
5033
5034
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 5032

def audience_source
  @audience_source
end

#audience_typeString

The type of the audience. Corresponds to the JSON property audienceType

Returns:

  • (String)


5037
5038
5039
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 5037

def audience_type
  @audience_type
end

#contact_info_listGoogle::Apis::DisplayvideoV1::ContactInfoList

Wrapper message for a list of contact information defining Customer Match audience members. Corresponds to the JSON property contactInfoList



5043
5044
5045
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 5043

def contact_info_list
  @contact_info_list
end

#descriptionString

The user-provided description of the audience. Only applicable to first party audiences. Corresponds to the JSON property description

Returns:

  • (String)


5049
5050
5051
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 5049

def description
  @description
end

#display_audience_sizeFixnum

Output only. The estimated audience size for the Display network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only returned in GET request. Corresponds to the JSON property displayAudienceSize

Returns:

  • (Fixnum)


5057
5058
5059
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 5057

def display_audience_size
  @display_audience_size
end

#display_desktop_audience_sizeFixnum

Output only. The estimated desktop audience size in Display network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request. Corresponds to the JSON property displayDesktopAudienceSize

Returns:

  • (Fixnum)


5066
5067
5068
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 5066

def display_desktop_audience_size
  @display_desktop_audience_size
end

#display_mobile_app_audience_sizeFixnum

Output only. The estimated mobile app audience size in Display network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request. Corresponds to the JSON property displayMobileAppAudienceSize

Returns:

  • (Fixnum)


5075
5076
5077
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 5075

def display_mobile_app_audience_size
  @display_mobile_app_audience_size
end

#display_mobile_web_audience_sizeFixnum

Output only. The estimated mobile web audience size in Display network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request. Corresponds to the JSON property displayMobileWebAudienceSize

Returns:

  • (Fixnum)


5084
5085
5086
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 5084

def display_mobile_web_audience_size
  @display_mobile_web_audience_size
end

#display_nameString

The display name of the first and third party audience. Corresponds to the JSON property displayName

Returns:

  • (String)


5089
5090
5091
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 5089

def display_name
  @display_name
end

#first_and_third_party_audience_idFixnum

Output only. The unique ID of the first and third party audience. Assigned by the system. Corresponds to the JSON property firstAndThirdPartyAudienceId

Returns:

  • (Fixnum)


5095
5096
5097
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 5095

def first_and_third_party_audience_id
  @first_and_third_party_audience_id
end

#first_and_third_party_audience_typeString

Whether the audience is a first or third party audience. Corresponds to the JSON property firstAndThirdPartyAudienceType

Returns:

  • (String)


5100
5101
5102
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 5100

def first_and_third_party_audience_type
  @first_and_third_party_audience_type
end

#gmail_audience_sizeFixnum

Output only. The estimated audience size for Gmail network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request. Corresponds to the JSON property gmailAudienceSize

Returns:

  • (Fixnum)


5108
5109
5110
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 5108

def gmail_audience_size
  @gmail_audience_size
end

#membership_duration_daysFixnum

The duration in days that an entry remains in the audience after the qualifying event. If the audience has no expiration, set the value of this field to 10000. Otherwise, the set value must be greater than 0 and less than or equal to 540. Only applicable to first party audiences. This field is required if one of the following audience_type is used: * CUSTOMER_MATCH_CONTACT_INFO * CUSTOMER_MATCH_DEVICE_ID Corresponds to the JSON property membershipDurationDays

Returns:

  • (Fixnum)


5118
5119
5120
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 5118

def membership_duration_days
  @membership_duration_days
end

#mobile_device_id_listGoogle::Apis::DisplayvideoV1::MobileDeviceIdList

Wrapper message for a list of mobile device IDs defining Customer Match audience members. Corresponds to the JSON property mobileDeviceIdList



5124
5125
5126
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 5124

def mobile_device_id_list
  @mobile_device_id_list
end

#nameString

Output only. The resource name of the first and third party audience. Corresponds to the JSON property name

Returns:

  • (String)


5129
5130
5131
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 5129

def name
  @name
end

#youtube_audience_sizeFixnum

Output only. The estimated audience size for YouTube network. If the size is less than 1000, the number will be hidden and 0 will be returned due to privacy reasons. Otherwise, the number will be rounded off to two significant digits. Only applicable to first party audiences. Only returned in GET request. Corresponds to the JSON property youtubeAudienceSize

Returns:

  • (Fixnum)


5137
5138
5139
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 5137

def youtube_audience_size
  @youtube_audience_size
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



5144
5145
5146
5147
5148
5149
5150
5151
5152
5153
5154
5155
5156
5157
5158
5159
5160
5161
5162
5163
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 5144

def update!(**args)
  @active_display_audience_size = args[:active_display_audience_size] if args.key?(:active_display_audience_size)
  @app_id = args[:app_id] if args.key?(:app_id)
  @audience_source = args[:audience_source] if args.key?(:audience_source)
  @audience_type = args[:audience_type] if args.key?(:audience_type)
  @contact_info_list = args[:contact_info_list] if args.key?(:contact_info_list)
  @description = args[:description] if args.key?(:description)
  @display_audience_size = args[:display_audience_size] if args.key?(:display_audience_size)
  @display_desktop_audience_size = args[:display_desktop_audience_size] if args.key?(:display_desktop_audience_size)
  @display_mobile_app_audience_size = args[:display_mobile_app_audience_size] if args.key?(:display_mobile_app_audience_size)
  @display_mobile_web_audience_size = args[:display_mobile_web_audience_size] if args.key?(:display_mobile_web_audience_size)
  @display_name = args[:display_name] if args.key?(:display_name)
  @first_and_third_party_audience_id = args[:first_and_third_party_audience_id] if args.key?(:first_and_third_party_audience_id)
  @first_and_third_party_audience_type = args[:first_and_third_party_audience_type] if args.key?(:first_and_third_party_audience_type)
  @gmail_audience_size = args[:gmail_audience_size] if args.key?(:gmail_audience_size)
  @membership_duration_days = args[:membership_duration_days] if args.key?(:membership_duration_days)
  @mobile_device_id_list = args[:mobile_device_id_list] if args.key?(:mobile_device_id_list)
  @name = args[:name] if args.key?(:name)
  @youtube_audience_size = args[:youtube_audience_size] if args.key?(:youtube_audience_size)
end