Class: Google::Apis::DisplayvideoV1::IntegrationDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v1/classes.rb,
lib/google/apis/displayvideo_v1/representations.rb,
lib/google/apis/displayvideo_v1/representations.rb

Overview

Integration details of an entry.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ IntegrationDetails

Returns a new instance of IntegrationDetails.



6209
6210
6211
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6209

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#detailsString

Additional details of the entry in string format. Must be UTF-8 encoded with a length of no more than 1000 characters. Corresponds to the JSON property details

Returns:

  • (String)


6200
6201
6202
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6200

def details
  @details
end

#integration_codeString

An external identifier to be associated with the entry. The integration code will show up together with the entry in many places in the system, for example, reporting. Must be UTF-8 encoded with a length of no more than 500 characters. Corresponds to the JSON property integrationCode

Returns:

  • (String)


6207
6208
6209
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6207

def integration_code
  @integration_code
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6214
6215
6216
6217
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6214

def update!(**args)
  @details = args[:details] if args.key?(:details)
  @integration_code = args[:integration_code] if args.key?(:integration_code)
end