Class: Google::Apis::DisplayvideoV1::InventorySource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v1/classes.rb,
lib/google/apis/displayvideo_v1/representations.rb,
lib/google/apis/displayvideo_v1/representations.rb

Overview

An inventory source.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InventorySource

Returns a new instance of InventorySource.



6334
6335
6336
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6334

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#commitmentString

Whether the inventory source has a guaranteed or non-guaranteed delivery. Corresponds to the JSON property commitment

Returns:

  • (String)


6227
6228
6229
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6227

def commitment
  @commitment
end

#creative_configsArray<Google::Apis::DisplayvideoV1::CreativeConfig>

The creative requirements of the inventory source. Not applicable for auction packages. Corresponds to the JSON property creativeConfigs



6233
6234
6235
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6233

def creative_configs
  @creative_configs
end

#deal_idString

The ID in the exchange space that uniquely identifies the inventory source. Must be unique across buyers within each exchange but not necessarily unique across exchanges. Corresponds to the JSON property dealId

Returns:

  • (String)


6240
6241
6242
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6240

def deal_id
  @deal_id
end

#delivery_methodString

The delivery method of the inventory source. * For non-guaranteed inventory sources, the only acceptable value is INVENTORY_SOURCE_DELIVERY_METHOD_PROGRAMMATIC. * For guaranteed inventory sources, acceptable values are INVENTORY_SOURCE_DELIVERY_METHOD_TAG and INVENTORY_SOURCE_DELIVERY_METHOD_PROGRAMMATIC. Corresponds to the JSON property deliveryMethod

Returns:

  • (String)


6249
6250
6251
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6249

def delivery_method
  @delivery_method
end

#display_nameString

The display name of the inventory source. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


6255
6256
6257
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6255

def display_name
  @display_name
end

#exchangeString

The exchange to which the inventory source belongs. Corresponds to the JSON property exchange

Returns:

  • (String)


6260
6261
6262
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6260

def exchange
  @exchange
end

#guaranteed_order_idString

Immutable. The ID of the guaranteed order that this inventory source belongs to. Only applicable when commitment is INVENTORY_SOURCE_COMMITMENT_GUARANTEED . Corresponds to the JSON property guaranteedOrderId

Returns:

  • (String)


6267
6268
6269
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6267

def guaranteed_order_id
  @guaranteed_order_id
end

#inventory_source_idFixnum

Output only. The unique ID of the inventory source. Assigned by the system. Corresponds to the JSON property inventorySourceId

Returns:

  • (Fixnum)


6272
6273
6274
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6272

def inventory_source_id
  @inventory_source_id
end

#inventory_source_product_typeString

Output only. The product type of the inventory source, denoting the way through which it sells inventory. Corresponds to the JSON property inventorySourceProductType

Returns:

  • (String)


6278
6279
6280
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6278

def inventory_source_product_type
  @inventory_source_product_type
end

#inventory_source_typeString

Denotes the type of the inventory source. Corresponds to the JSON property inventorySourceType

Returns:

  • (String)


6283
6284
6285
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6283

def inventory_source_type
  @inventory_source_type
end

#nameString

Output only. The resource name of the inventory source. Corresponds to the JSON property name

Returns:

  • (String)


6288
6289
6290
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6288

def name
  @name
end

#publisher_nameString

The publisher/seller name of the inventory source. Corresponds to the JSON property publisherName

Returns:

  • (String)


6293
6294
6295
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6293

def publisher_name
  @publisher_name
end

#rate_detailsGoogle::Apis::DisplayvideoV1::RateDetails

The rate related settings of the inventory source. Corresponds to the JSON property rateDetails



6298
6299
6300
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6298

def rate_details
  @rate_details
end

#read_advertiser_idsArray<Fixnum>

Output only. The IDs of advertisers with read-only access to the inventory source. Corresponds to the JSON property readAdvertiserIds

Returns:

  • (Array<Fixnum>)


6304
6305
6306
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6304

def read_advertiser_ids
  @read_advertiser_ids
end

#read_partner_idsArray<Fixnum>

Output only. The IDs of partners with read-only access to the inventory source. All advertisers of partners in this field inherit read-only access to the inventory source. Corresponds to the JSON property readPartnerIds

Returns:

  • (Array<Fixnum>)


6311
6312
6313
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6311

def read_partner_ids
  @read_partner_ids
end

#read_write_accessorsGoogle::Apis::DisplayvideoV1::InventorySourceAccessors

The partner or advertisers with access to the inventory source. Corresponds to the JSON property readWriteAccessors



6316
6317
6318
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6316

def read_write_accessors
  @read_write_accessors
end

#statusGoogle::Apis::DisplayvideoV1::InventorySourceStatus

The status related settings of the inventory source. Corresponds to the JSON property status



6321
6322
6323
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6321

def status
  @status
end

#time_rangeGoogle::Apis::DisplayvideoV1::TimeRange

A time range. Corresponds to the JSON property timeRange



6326
6327
6328
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6326

def time_range
  @time_range
end

#update_timeString

Output only. The timestamp when the inventory source was last updated. Assigned by the system. Corresponds to the JSON property updateTime

Returns:

  • (String)


6332
6333
6334
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6332

def update_time
  @update_time
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6339
6340
6341
6342
6343
6344
6345
6346
6347
6348
6349
6350
6351
6352
6353
6354
6355
6356
6357
6358
6359
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6339

def update!(**args)
  @commitment = args[:commitment] if args.key?(:commitment)
  @creative_configs = args[:creative_configs] if args.key?(:creative_configs)
  @deal_id = args[:deal_id] if args.key?(:deal_id)
  @delivery_method = args[:delivery_method] if args.key?(:delivery_method)
  @display_name = args[:display_name] if args.key?(:display_name)
  @exchange = args[:exchange] if args.key?(:exchange)
  @guaranteed_order_id = args[:guaranteed_order_id] if args.key?(:guaranteed_order_id)
  @inventory_source_id = args[:inventory_source_id] if args.key?(:inventory_source_id)
  @inventory_source_product_type = args[:inventory_source_product_type] if args.key?(:inventory_source_product_type)
  @inventory_source_type = args[:inventory_source_type] if args.key?(:inventory_source_type)
  @name = args[:name] if args.key?(:name)
  @publisher_name = args[:publisher_name] if args.key?(:publisher_name)
  @rate_details = args[:rate_details] if args.key?(:rate_details)
  @read_advertiser_ids = args[:read_advertiser_ids] if args.key?(:read_advertiser_ids)
  @read_partner_ids = args[:read_partner_ids] if args.key?(:read_partner_ids)
  @read_write_accessors = args[:read_write_accessors] if args.key?(:read_write_accessors)
  @status = args[:status] if args.key?(:status)
  @time_range = args[:time_range] if args.key?(:time_range)
  @update_time = args[:update_time] if args.key?(:update_time)
end