Class: Google::Apis::DisplayvideoV1::InventorySourceStatus

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v1/classes.rb,
lib/google/apis/displayvideo_v1/representations.rb,
lib/google/apis/displayvideo_v1/representations.rb

Overview

The status related settings of the inventory source.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ InventorySourceStatus

Returns a new instance of InventorySourceStatus.



6584
6585
6586
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6584

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#config_statusString

Output only. The configuration status of the inventory source. Only applicable for guaranteed inventory sources. Acceptable values are INVENTORY_SOURCE_CONFIG_STATUS_PENDING and INVENTORY_SOURCE_CONFIG_STATUS_COMPLETED. An inventory source must be configured (fill in the required fields, choose creatives, and select a default campaign) before it can serve. Corresponds to the JSON property configStatus

Returns:

  • (String)


6554
6555
6556
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6554

def config_status
  @config_status
end

#entity_pause_reasonString

The user-provided reason for pausing this inventory source. Must not exceed 100 characters. Only applicable when entity_status is set to ENTITY_STATUS_PAUSED. Corresponds to the JSON property entityPauseReason

Returns:

  • (String)


6561
6562
6563
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6561

def entity_pause_reason
  @entity_pause_reason
end

#entity_statusString

Whether or not the inventory source is servable. Acceptable values are ENTITY_STATUS_ACTIVE, ENTITY_STATUS_ARCHIVED, and ENTITY_STATUS_PAUSED. Default value is ENTITY_STATUS_ACTIVE. Corresponds to the JSON property entityStatus

Returns:

  • (String)


6568
6569
6570
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6568

def entity_status
  @entity_status
end

#seller_pause_reasonString

Output only. The seller-provided reason for pausing this inventory source. Only applicable for inventory sources synced directly from the publishers and when seller_status is set to ENTITY_STATUS_PAUSED. Corresponds to the JSON property sellerPauseReason

Returns:

  • (String)


6575
6576
6577
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6575

def seller_pause_reason
  @seller_pause_reason
end

#seller_statusString

Output only. The status set by the seller for the inventory source. Only applicable for inventory sources synced directly from the publishers. Acceptable values are ENTITY_STATUS_ACTIVE and ENTITY_STATUS_PAUSED. Corresponds to the JSON property sellerStatus

Returns:

  • (String)


6582
6583
6584
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6582

def seller_status
  @seller_status
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6589
6590
6591
6592
6593
6594
6595
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6589

def update!(**args)
  @config_status = args[:config_status] if args.key?(:config_status)
  @entity_pause_reason = args[:entity_pause_reason] if args.key?(:entity_pause_reason)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @seller_pause_reason = args[:seller_pause_reason] if args.key?(:seller_pause_reason)
  @seller_status = args[:seller_status] if args.key?(:seller_status)
end