Class: Google::Apis::DisplayvideoV1::LineItem

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v1/classes.rb,
lib/google/apis/displayvideo_v1/representations.rb,
lib/google/apis/displayvideo_v1/representations.rb

Overview

A single line item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LineItem

Returns a new instance of LineItem.



7022
7023
7024
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 7022

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Output only. The unique ID of the advertiser the line item belongs to. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


6881
6882
6883
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6881

def advertiser_id
  @advertiser_id
end

#bid_strategyGoogle::Apis::DisplayvideoV1::BiddingStrategy

Settings that control the bid strategy. Bid strategy determines the bid price. Corresponds to the JSON property bidStrategy



6886
6887
6888
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6886

def bid_strategy
  @bid_strategy
end

#budgetGoogle::Apis::DisplayvideoV1::LineItemBudget

Settings that control how budget is allocated. Corresponds to the JSON property budget



6891
6892
6893
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6891

def budget
  @budget
end

#campaign_idFixnum

Output only. The unique ID of the campaign that the line item belongs to. Corresponds to the JSON property campaignId

Returns:

  • (Fixnum)


6896
6897
6898
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6896

def campaign_id
  @campaign_id
end

#conversion_countingGoogle::Apis::DisplayvideoV1::ConversionCountingConfig

Settings that control how conversions are counted. All post-click conversions will be counted. A percentage value can be set for post-view conversions counting. Corresponds to the JSON property conversionCounting



6903
6904
6905
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6903

def conversion_counting
  @conversion_counting
end

#creative_idsArray<Fixnum>

The IDs of the creatives associated with the line item. Corresponds to the JSON property creativeIds

Returns:

  • (Array<Fixnum>)


6908
6909
6910
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6908

def creative_ids
  @creative_ids
end

#display_nameString

Required. The display name of the line item. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


6914
6915
6916
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6914

def display_name
  @display_name
end

#entity_statusString

Required. Controls whether or not the line item can spend its budget and bid on inventory. * For CreateLineItem method, only ENTITY_STATUS_DRAFT is allowed. To activate a line item, use UpdateLineItem method and update the status to ENTITY_STATUS_ACTIVE after creation. * A line item cannot be changed back to ENTITY_STATUS_DRAFT status from any other status. * If the line item's parent insertion order is not active, the line item can't spend its budget even if its own status is ENTITY_STATUS_ACTIVE. Corresponds to the JSON property entityStatus

Returns:

  • (String)


6925
6926
6927
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6925

def entity_status
  @entity_status
end

#exclude_new_exchangesBoolean Also known as: exclude_new_exchanges?

Whether to exclude new exchanges from automatically being targeted by the line item. This field is false by default. Corresponds to the JSON property excludeNewExchanges

Returns:

  • (Boolean)


6931
6932
6933
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6931

def exclude_new_exchanges
  @exclude_new_exchanges
end

#flightGoogle::Apis::DisplayvideoV1::LineItemFlight

Settings that control the active duration of a line item. Corresponds to the JSON property flight



6937
6938
6939
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6937

def flight
  @flight
end

#frequency_capGoogle::Apis::DisplayvideoV1::FrequencyCap

Settings that control the number of times a user may be shown with the same ad during a given time period. Corresponds to the JSON property frequencyCap



6943
6944
6945
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6943

def frequency_cap
  @frequency_cap
end

#insertion_order_idFixnum

Required. Immutable. The unique ID of the insertion order that the line item belongs to. Corresponds to the JSON property insertionOrderId

Returns:

  • (Fixnum)


6949
6950
6951
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6949

def insertion_order_id
  @insertion_order_id
end

#integration_detailsGoogle::Apis::DisplayvideoV1::IntegrationDetails

Integration details of an entry. Corresponds to the JSON property integrationDetails



6954
6955
6956
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6954

def integration_details
  @integration_details
end

#inventory_source_idsArray<Fixnum>

The IDs of the private inventory sources assigned to the line item. Corresponds to the JSON property inventorySourceIds

Returns:

  • (Array<Fixnum>)


6959
6960
6961
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6959

def inventory_source_ids
  @inventory_source_ids
end

#line_item_idFixnum

Output only. The unique ID of the line item. Assigned by the system. Corresponds to the JSON property lineItemId

Returns:

  • (Fixnum)


6964
6965
6966
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6964

def line_item_id
  @line_item_id
end

#line_item_typeString

Required. Immutable. The type of the line item. Corresponds to the JSON property lineItemType

Returns:

  • (String)


6969
6970
6971
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6969

def line_item_type
  @line_item_type
end

#mobile_appGoogle::Apis::DisplayvideoV1::MobileApp

A mobile app promoted by a mobile app install line item. Corresponds to the JSON property mobileApp



6974
6975
6976
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6974

def mobile_app
  @mobile_app
end

#nameString

Output only. The resource name of the line item. Corresponds to the JSON property name

Returns:

  • (String)


6979
6980
6981
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6979

def name
  @name
end

#pacingGoogle::Apis::DisplayvideoV1::Pacing

Settings that control the rate at which a budget is spent. Corresponds to the JSON property pacing



6984
6985
6986
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6984

def pacing
  @pacing
end

#partner_costsArray<Google::Apis::DisplayvideoV1::PartnerCost>

The partner costs associated with the line item. If absent or empty in CreateLineItem method, the newly created line item will inherit partner costs from its parent insertion order. Corresponds to the JSON property partnerCosts



6991
6992
6993
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6991

def partner_costs
  @partner_costs
end

#partner_revenue_modelGoogle::Apis::DisplayvideoV1::PartnerRevenueModel

Settings that control how partner revenue is calculated. Corresponds to the JSON property partnerRevenueModel



6996
6997
6998
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 6996

def partner_revenue_model
  @partner_revenue_model
end

#reservation_typeString

Output only. The reservation type of the line item. Corresponds to the JSON property reservationType

Returns:

  • (String)


7001
7002
7003
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 7001

def reservation_type
  @reservation_type
end

#targeting_expansionGoogle::Apis::DisplayvideoV1::TargetingExpansionConfig

Settings that control the optimized targeting settings of the line item. Corresponds to the JSON property targetingExpansion



7007
7008
7009
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 7007

def targeting_expansion
  @targeting_expansion
end

#update_timeString

Output only. The timestamp when the line item was last updated. Assigned by the system. Corresponds to the JSON property updateTime

Returns:

  • (String)


7013
7014
7015
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 7013

def update_time
  @update_time
end

#warning_messagesArray<String>

Output only. The warning messages generated by the line item. These warnings do not block saving the line item, but some may block the line item from running. Corresponds to the JSON property warningMessages

Returns:

  • (Array<String>)


7020
7021
7022
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 7020

def warning_messages
  @warning_messages
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7027
7028
7029
7030
7031
7032
7033
7034
7035
7036
7037
7038
7039
7040
7041
7042
7043
7044
7045
7046
7047
7048
7049
7050
7051
7052
7053
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 7027

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @bid_strategy = args[:bid_strategy] if args.key?(:bid_strategy)
  @budget = args[:budget] if args.key?(:budget)
  @campaign_id = args[:campaign_id] if args.key?(:campaign_id)
  @conversion_counting = args[:conversion_counting] if args.key?(:conversion_counting)
  @creative_ids = args[:creative_ids] if args.key?(:creative_ids)
  @display_name = args[:display_name] if args.key?(:display_name)
  @entity_status = args[:entity_status] if args.key?(:entity_status)
  @exclude_new_exchanges = args[:exclude_new_exchanges] if args.key?(:exclude_new_exchanges)
  @flight = args[:flight] if args.key?(:flight)
  @frequency_cap = args[:frequency_cap] if args.key?(:frequency_cap)
  @insertion_order_id = args[:insertion_order_id] if args.key?(:insertion_order_id)
  @integration_details = args[:integration_details] if args.key?(:integration_details)
  @inventory_source_ids = args[:inventory_source_ids] if args.key?(:inventory_source_ids)
  @line_item_id = args[:line_item_id] if args.key?(:line_item_id)
  @line_item_type = args[:line_item_type] if args.key?(:line_item_type)
  @mobile_app = args[:mobile_app] if args.key?(:mobile_app)
  @name = args[:name] if args.key?(:name)
  @pacing = args[:pacing] if args.key?(:pacing)
  @partner_costs = args[:partner_costs] if args.key?(:partner_costs)
  @partner_revenue_model = args[:partner_revenue_model] if args.key?(:partner_revenue_model)
  @reservation_type = args[:reservation_type] if args.key?(:reservation_type)
  @targeting_expansion = args[:targeting_expansion] if args.key?(:targeting_expansion)
  @update_time = args[:update_time] if args.key?(:update_time)
  @warning_messages = args[:warning_messages] if args.key?(:warning_messages)
end