Class: Google::Apis::DisplayvideoV1::ListCustomBiddingAlgorithmsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV1::ListCustomBiddingAlgorithmsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v1/classes.rb,
lib/google/apis/displayvideo_v1/representations.rb,
lib/google/apis/displayvideo_v1/representations.rb
Instance Attribute Summary collapse
-
#custom_bidding_algorithms ⇒ Array<Google::Apis::DisplayvideoV1::CustomBiddingAlgorithm>
The list of custom bidding algorithms.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCustomBiddingAlgorithmsResponse
constructor
A new instance of ListCustomBiddingAlgorithmsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCustomBiddingAlgorithmsResponse
Returns a new instance of ListCustomBiddingAlgorithmsResponse.
7402 7403 7404 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 7402 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_bidding_algorithms ⇒ Array<Google::Apis::DisplayvideoV1::CustomBiddingAlgorithm>
The list of custom bidding algorithms. This list will be absent if empty.
Corresponds to the JSON property customBiddingAlgorithms
7392 7393 7394 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 7392 def custom_bidding_algorithms @custom_bidding_algorithms end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListCustomBiddingAlgorithmsRequest
method to retrieve the next page of results. If this field is null, it means
this is the last page.
Corresponds to the JSON property nextPageToken
7400 7401 7402 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 7400 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7407 7408 7409 7410 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 7407 def update!(**args) @custom_bidding_algorithms = args[:custom_bidding_algorithms] if args.key?(:custom_bidding_algorithms) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |