Class: Google::Apis::DisplayvideoV1::ListFirstAndThirdPartyAudiencesResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v1/classes.rb,
lib/google/apis/displayvideo_v1/representations.rb,
lib/google/apis/displayvideo_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListFirstAndThirdPartyAudiencesResponse

Returns a new instance of ListFirstAndThirdPartyAudiencesResponse.



7485
7486
7487
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 7485

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#first_and_third_party_audiencesArray<Google::Apis::DisplayvideoV1::FirstAndThirdPartyAudience>

The list of first and third party audiences. Audience size properties will not be included. This list will be absent if empty. Corresponds to the JSON property firstAndThirdPartyAudiences



7476
7477
7478
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 7476

def first_and_third_party_audiences
  @first_and_third_party_audiences
end

#next_page_tokenString

A token to retrieve the next page of results. Pass this value in the page_token field in the subsequent call to ListFirstAndThirdPartyAudiences method to retrieve the next page of results. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


7483
7484
7485
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 7483

def next_page_token
  @next_page_token
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7490
7491
7492
7493
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 7490

def update!(**args)
  @first_and_third_party_audiences = args[:first_and_third_party_audiences] if args.key?(:first_and_third_party_audiences)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
end