Class: Google::Apis::DisplayvideoV1::LocationList

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v1/classes.rb,
lib/google/apis/displayvideo_v1/representations.rb,
lib/google/apis/displayvideo_v1/representations.rb

Overview

A list of locations used for targeting.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LocationList

Returns a new instance of LocationList.



8020
8021
8022
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 8020

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#advertiser_idFixnum

Required. Immutable. The unique ID of the advertiser the location list belongs to. Corresponds to the JSON property advertiserId

Returns:

  • (Fixnum)


7996
7997
7998
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 7996

def advertiser_id
  @advertiser_id
end

#display_nameString

Required. The display name of the location list. Must be UTF-8 encoded with a maximum size of 240 bytes. Corresponds to the JSON property displayName

Returns:

  • (String)


8002
8003
8004
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 8002

def display_name
  @display_name
end

#location_list_idFixnum

Output only. The unique ID of the location list. Assigned by the system. Corresponds to the JSON property locationListId

Returns:

  • (Fixnum)


8007
8008
8009
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 8007

def location_list_id
  @location_list_id
end

#location_typeString

Required. Immutable. The type of location. All locations in the list will share this type. Corresponds to the JSON property locationType

Returns:

  • (String)


8013
8014
8015
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 8013

def location_type
  @location_type
end

#nameString

Output only. The resource name of the location list. Corresponds to the JSON property name

Returns:

  • (String)


8018
8019
8020
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 8018

def name
  @name
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8025
8026
8027
8028
8029
8030
8031
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 8025

def update!(**args)
  @advertiser_id = args[:advertiser_id] if args.key?(:advertiser_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @location_list_id = args[:location_list_id] if args.key?(:location_list_id)
  @location_type = args[:location_type] if args.key?(:location_type)
  @name = args[:name] if args.key?(:name)
end