Class: Google::Apis::DisplayvideoV1::MobileApp

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v1/classes.rb,
lib/google/apis/displayvideo_v1/representations.rb,
lib/google/apis/displayvideo_v1/representations.rb

Overview

A mobile app promoted by a mobile app install line item.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MobileApp

Returns a new instance of MobileApp.



8244
8245
8246
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 8244

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#app_idString

Required. The ID of the app provided by the platform store. Android apps are identified by the bundle ID used by Android's Play store, such as com.google. android.gm. iOS apps are identified by a nine-digit app ID used by Apple's App store, such as 422689480. Corresponds to the JSON property appId

Returns:

  • (String)


8227
8228
8229
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 8227

def app_id
  @app_id
end

#display_nameString

Output only. The app name. Corresponds to the JSON property displayName

Returns:

  • (String)


8232
8233
8234
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 8232

def display_name
  @display_name
end

#platformString

Output only. The app platform. Corresponds to the JSON property platform

Returns:

  • (String)


8237
8238
8239
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 8237

def platform
  @platform
end

#publisherString

Output only. The app publisher. Corresponds to the JSON property publisher

Returns:

  • (String)


8242
8243
8244
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 8242

def publisher
  @publisher
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8249
8250
8251
8252
8253
8254
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 8249

def update!(**args)
  @app_id = args[:app_id] if args.key?(:app_id)
  @display_name = args[:display_name] if args.key?(:display_name)
  @platform = args[:platform] if args.key?(:platform)
  @publisher = args[:publisher] if args.key?(:publisher)
end