Class: Google::Apis::DisplayvideoV1::ProximityLocationListAssignedTargetingOptionDetails
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV1::ProximityLocationListAssignedTargetingOptionDetails
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v1/classes.rb,
lib/google/apis/displayvideo_v1/representations.rb,
lib/google/apis/displayvideo_v1/representations.rb
Overview
Targeting details for proximity location list. This will be populated in the
details field of an AssignedTargetingOption when targeting_type is
TARGETING_TYPE_PROXIMITY_LOCATION_LIST.
Instance Attribute Summary collapse
-
#proximity_location_list_id ⇒ Fixnum
Required.
-
#proximity_radius_range ⇒ String
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ProximityLocationListAssignedTargetingOptionDetails
constructor
A new instance of ProximityLocationListAssignedTargetingOptionDetails.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ProximityLocationListAssignedTargetingOptionDetails
Returns a new instance of ProximityLocationListAssignedTargetingOptionDetails.
9438 9439 9440 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 9438 def initialize(**args) update!(**args) end |
Instance Attribute Details
#proximity_location_list_id ⇒ Fixnum
Required. ID of the proximity location list. Should refer to the
location_list_id field of a LocationList resource whose type is
TARGETING_LOCATION_TYPE_PROXIMITY.
Corresponds to the JSON property proximityLocationListId
9427 9428 9429 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 9427 def proximity_location_list_id @proximity_location_list_id end |
#proximity_radius_range ⇒ String
Required. Radius range for proximity location list. This represents the size
of the area around a chosen location that will be targeted. All proximity
location targeting under a single resource must have the same radius range
value. Set this value to match any existing targeting. If updated, this field
will change the radius range for all proximity targeting under the resource.
Corresponds to the JSON property proximityRadiusRange
9436 9437 9438 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 9436 def proximity_radius_range @proximity_radius_range end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9443 9444 9445 9446 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 9443 def update!(**args) @proximity_location_list_id = args[:proximity_location_list_id] if args.key?(:proximity_location_list_id) @proximity_radius_range = args[:proximity_radius_range] if args.key?(:proximity_radius_range) end |