Class: Google::Apis::DisplayvideoV1::RateDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v1/classes.rb,
lib/google/apis/displayvideo_v1/representations.rb,
lib/google/apis/displayvideo_v1/representations.rb

Overview

The rate related settings of the inventory source.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RateDetails

Returns a new instance of RateDetails.



9500
9501
9502
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 9500

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#inventory_source_rate_typeString

The rate type. Acceptable values are INVENTORY_SOURCE_RATE_TYPE_CPM_FIXED, INVENTORY_SOURCE_RATE_TYPE_CPM_FLOOR, and INVENTORY_SOURCE_RATE_TYPE_CPD. Corresponds to the JSON property inventorySourceRateType

Returns:

  • (String)


9482
9483
9484
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 9482

def inventory_source_rate_type
  @inventory_source_rate_type
end

#minimum_spendGoogle::Apis::DisplayvideoV1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property minimumSpend



9487
9488
9489
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 9487

def minimum_spend
  @minimum_spend
end

#rateGoogle::Apis::DisplayvideoV1::Money

Represents an amount of money with its currency type. Corresponds to the JSON property rate



9492
9493
9494
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 9492

def rate
  @rate
end

#units_purchasedFixnum

Required for guaranteed inventory sources. The number of impressions guaranteed by the seller. Corresponds to the JSON property unitsPurchased

Returns:

  • (Fixnum)


9498
9499
9500
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 9498

def units_purchased
  @units_purchased
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9505
9506
9507
9508
9509
9510
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 9505

def update!(**args)
  @inventory_source_rate_type = args[:inventory_source_rate_type] if args.key?(:inventory_source_rate_type)
  @minimum_spend = args[:minimum_spend] if args.key?(:minimum_spend)
  @rate = args[:rate] if args.key?(:rate)
  @units_purchased = args[:units_purchased] if args.key?(:units_purchased)
end