Class: Google::Apis::DisplayvideoV1::Transcode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/displayvideo_v1/classes.rb,
lib/google/apis/displayvideo_v1/representations.rb,
lib/google/apis/displayvideo_v1/representations.rb

Overview

Represents information about the transcoded audio or video file.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Transcode

Returns a new instance of Transcode.



10584
10585
10586
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 10584

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#audio_bit_rate_kbpsFixnum

The bit rate for the audio stream of the transcoded video, or the bit rate for the transcoded audio, in kilobits per second. Corresponds to the JSON property audioBitRateKbps

Returns:

  • (Fixnum)


10540
10541
10542
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 10540

def audio_bit_rate_kbps
  @audio_bit_rate_kbps
end

#audio_sample_rate_hzFixnum

The sample rate for the audio stream of the transcoded video, or the sample rate for the transcoded audio, in hertz. Corresponds to the JSON property audioSampleRateHz

Returns:

  • (Fixnum)


10546
10547
10548
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 10546

def audio_sample_rate_hz
  @audio_sample_rate_hz
end

#bit_rate_kbpsFixnum

The transcoding bit rate of the transcoded video, in kilobits per second. Corresponds to the JSON property bitRateKbps

Returns:

  • (Fixnum)


10551
10552
10553
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 10551

def bit_rate_kbps
  @bit_rate_kbps
end

#dimensionsGoogle::Apis::DisplayvideoV1::Dimensions

Dimensions. Corresponds to the JSON property dimensions



10556
10557
10558
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 10556

def dimensions
  @dimensions
end

#file_size_bytesFixnum

The size of the transcoded file, in bytes. Corresponds to the JSON property fileSizeBytes

Returns:

  • (Fixnum)


10561
10562
10563
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 10561

def file_size_bytes
  @file_size_bytes
end

#frame_rateFloat

The frame rate of the transcoded video, in frames per second. Corresponds to the JSON property frameRate

Returns:

  • (Float)


10566
10567
10568
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 10566

def frame_rate
  @frame_rate
end

#mime_typeString

The MIME type of the transcoded file. Corresponds to the JSON property mimeType

Returns:

  • (String)


10571
10572
10573
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 10571

def mime_type
  @mime_type
end

#nameString

The name of the transcoded file. Corresponds to the JSON property name

Returns:

  • (String)


10576
10577
10578
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 10576

def name
  @name
end

#transcodedBoolean Also known as: transcoded?

Indicates if the transcoding was successful. Corresponds to the JSON property transcoded

Returns:

  • (Boolean)


10581
10582
10583
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 10581

def transcoded
  @transcoded
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



10589
10590
10591
10592
10593
10594
10595
10596
10597
10598
10599
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 10589

def update!(**args)
  @audio_bit_rate_kbps = args[:audio_bit_rate_kbps] if args.key?(:audio_bit_rate_kbps)
  @audio_sample_rate_hz = args[:audio_sample_rate_hz] if args.key?(:audio_sample_rate_hz)
  @bit_rate_kbps = args[:bit_rate_kbps] if args.key?(:bit_rate_kbps)
  @dimensions = args[:dimensions] if args.key?(:dimensions)
  @file_size_bytes = args[:file_size_bytes] if args.key?(:file_size_bytes)
  @frame_rate = args[:frame_rate] if args.key?(:frame_rate)
  @mime_type = args[:mime_type] if args.key?(:mime_type)
  @name = args[:name] if args.key?(:name)
  @transcoded = args[:transcoded] if args.key?(:transcoded)
end