Class: Google::Apis::DisplayvideoV1::FirstAndThirdPartyAudienceGroup
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV1::FirstAndThirdPartyAudienceGroup
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v1/classes.rb,
lib/google/apis/displayvideo_v1/representations.rb,
lib/google/apis/displayvideo_v1/representations.rb
Overview
Details of first and third party audience group. All first and third party audience targeting settings are logically ‘OR’ of each other.
Instance Attribute Summary collapse
-
#settings ⇒ Array<Google::Apis::DisplayvideoV1::FirstAndThirdPartyAudienceTargetingSetting>
Required.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FirstAndThirdPartyAudienceGroup
constructor
A new instance of FirstAndThirdPartyAudienceGroup.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FirstAndThirdPartyAudienceGroup
Returns a new instance of FirstAndThirdPartyAudienceGroup.
5177 5178 5179 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 5177 def initialize(**args) update!(**args) end |
Instance Attribute Details
#settings ⇒ Array<Google::Apis::DisplayvideoV1::FirstAndThirdPartyAudienceTargetingSetting>
Required. All first and third party audience targeting settings in first and
third party audience group. Repeated settings with same id are not allowed.
Corresponds to the JSON property settings
5175 5176 5177 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 5175 def settings @settings end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5182 5183 5184 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 5182 def update!(**args) @settings = args[:settings] if args.key?(:settings) end |