Class: Google::Apis::DisplayvideoV1::ListCustomBiddingScriptsResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV1::ListCustomBiddingScriptsResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v1/classes.rb,
lib/google/apis/displayvideo_v1/representations.rb,
lib/google/apis/displayvideo_v1/representations.rb
Instance Attribute Summary collapse
-
#custom_bidding_scripts ⇒ Array<Google::Apis::DisplayvideoV1::CustomBiddingScript>
The list of custom bidding scripts.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListCustomBiddingScriptsResponse
constructor
A new instance of ListCustomBiddingScriptsResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListCustomBiddingScriptsResponse
Returns a new instance of ListCustomBiddingScriptsResponse.
7430 7431 7432 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 7430 def initialize(**args) update!(**args) end |
Instance Attribute Details
#custom_bidding_scripts ⇒ Array<Google::Apis::DisplayvideoV1::CustomBiddingScript>
The list of custom bidding scripts. This list will be absent if empty.
Corresponds to the JSON property customBiddingScripts
7420 7421 7422 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 7420 def custom_bidding_scripts @custom_bidding_scripts end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListCustomBiddingScriptsRequest
method to retrieve the next page of results. If this field is null, it means
this is the last page.
Corresponds to the JSON property nextPageToken
7428 7429 7430 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 7428 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7435 7436 7437 7438 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 7435 def update!(**args) @custom_bidding_scripts = args[:custom_bidding_scripts] if args.key?(:custom_bidding_scripts) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |