Class: Google::Apis::DisplayvideoV1::ListInvoicesResponse
- Inherits:
-
Object
- Object
- Google::Apis::DisplayvideoV1::ListInvoicesResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/displayvideo_v1/classes.rb,
lib/google/apis/displayvideo_v1/representations.rb,
lib/google/apis/displayvideo_v1/representations.rb
Instance Attribute Summary collapse
-
#invoices ⇒ Array<Google::Apis::DisplayvideoV1::Invoice>
The list of invoices.
-
#next_page_token ⇒ String
A token to retrieve the next page of results.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListInvoicesResponse
constructor
A new instance of ListInvoicesResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListInvoicesResponse
Returns a new instance of ListInvoicesResponse.
7677 7678 7679 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 7677 def initialize(**args) update!(**args) end |
Instance Attribute Details
#invoices ⇒ Array<Google::Apis::DisplayvideoV1::Invoice>
The list of invoices. This list will be absent if empty.
Corresponds to the JSON property invoices
7667 7668 7669 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 7667 def invoices @invoices end |
#next_page_token ⇒ String
A token to retrieve the next page of results. Pass this value in the
page_token field in the subsequent call to ListInvoices method to retrieve
the next page of results. This token will be absent if there are no more
invoices to return.
Corresponds to the JSON property nextPageToken
7675 7676 7677 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 7675 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7682 7683 7684 7685 |
# File 'lib/google/apis/displayvideo_v1/classes.rb', line 7682 def update!(**args) @invoices = args[:invoices] if args.key?(:invoices) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |